from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI
import win32more.Windows.Foundation
import win32more.Windows.UI
class ClosableNotifierHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{478cec68-ea8e-52fc-87e2-c819de000f92}')
    @winrt_commethod(3)
    def Invoke(self) -> Void: ...
class ColorHelper(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.IColorHelper
    _classid_ = 'Microsoft.UI.ColorHelper'
    @winrt_classmethod
    def ToDisplayName(cls: win32more.Microsoft.UI.IColorHelperStatics2, color: win32more.Windows.UI.Color) -> WinRT_String: ...
    @winrt_classmethod
    def FromArgb(cls: win32more.Microsoft.UI.IColorHelperStatics, a: Byte, r: Byte, g: Byte, b: Byte) -> win32more.Windows.UI.Color: ...
class _Colors_Meta_(ComPtr.__class__):
    pass
class Colors(ComPtr, metaclass=_Colors_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.IColors
    _classid_ = 'Microsoft.UI.Colors'
    @winrt_classmethod
    def get_AliceBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_AntiqueWhite(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Aqua(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Aquamarine(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Azure(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Beige(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Bisque(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Black(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_BlanchedAlmond(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Blue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_BlueViolet(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Brown(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_BurlyWood(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_CadetBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Chartreuse(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Chocolate(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Coral(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_CornflowerBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Cornsilk(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Crimson(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Cyan(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkCyan(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkGoldenrod(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkKhaki(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkMagenta(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkOliveGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkOrange(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkOrchid(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkSalmon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkSeaGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkSlateBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkSlateGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkTurquoise(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DarkViolet(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DeepPink(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DeepSkyBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DimGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_DodgerBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Firebrick(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_FloralWhite(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_ForestGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Fuchsia(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Gainsboro(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_GhostWhite(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Gold(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Goldenrod(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Gray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Green(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_GreenYellow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Honeydew(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_HotPink(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_IndianRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Indigo(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Ivory(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Khaki(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Lavender(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LavenderBlush(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LawnGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LemonChiffon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightCoral(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightCyan(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightGoldenrodYellow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightPink(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSalmon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSeaGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSkyBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSlateGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightSteelBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LightYellow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Lime(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_LimeGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Linen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Magenta(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Maroon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumAquamarine(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumOrchid(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumPurple(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumSeaGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumSlateBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumSpringGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumTurquoise(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MediumVioletRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MidnightBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MintCream(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_MistyRose(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Moccasin(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_NavajoWhite(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Navy(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_OldLace(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Olive(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_OliveDrab(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Orange(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_OrangeRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Orchid(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PaleGoldenrod(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PaleGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PaleTurquoise(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PaleVioletRed(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PapayaWhip(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PeachPuff(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Peru(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Pink(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Plum(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_PowderBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Purple(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Red(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_RosyBrown(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_RoyalBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SaddleBrown(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Salmon(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SandyBrown(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SeaGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SeaShell(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Sienna(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Silver(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SkyBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SlateBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SlateGray(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Snow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SpringGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_SteelBlue(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Tan(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Teal(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Thistle(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Tomato(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Transparent(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Turquoise(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Violet(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Wheat(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_White(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_WhiteSmoke(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_Yellow(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    @winrt_classmethod
    def get_YellowGreen(cls: win32more.Microsoft.UI.IColorsStatics) -> win32more.Windows.UI.Color: ...
    _Colors_Meta_.AliceBlue = property(get_AliceBlue, None)
    _Colors_Meta_.AntiqueWhite = property(get_AntiqueWhite, None)
    _Colors_Meta_.Aqua = property(get_Aqua, None)
    _Colors_Meta_.Aquamarine = property(get_Aquamarine, None)
    _Colors_Meta_.Azure = property(get_Azure, None)
    _Colors_Meta_.Beige = property(get_Beige, None)
    _Colors_Meta_.Bisque = property(get_Bisque, None)
    _Colors_Meta_.Black = property(get_Black, None)
    _Colors_Meta_.BlanchedAlmond = property(get_BlanchedAlmond, None)
    _Colors_Meta_.Blue = property(get_Blue, None)
    _Colors_Meta_.BlueViolet = property(get_BlueViolet, None)
    _Colors_Meta_.Brown = property(get_Brown, None)
    _Colors_Meta_.BurlyWood = property(get_BurlyWood, None)
    _Colors_Meta_.CadetBlue = property(get_CadetBlue, None)
    _Colors_Meta_.Chartreuse = property(get_Chartreuse, None)
    _Colors_Meta_.Chocolate = property(get_Chocolate, None)
    _Colors_Meta_.Coral = property(get_Coral, None)
    _Colors_Meta_.CornflowerBlue = property(get_CornflowerBlue, None)
    _Colors_Meta_.Cornsilk = property(get_Cornsilk, None)
    _Colors_Meta_.Crimson = property(get_Crimson, None)
    _Colors_Meta_.Cyan = property(get_Cyan, None)
    _Colors_Meta_.DarkBlue = property(get_DarkBlue, None)
    _Colors_Meta_.DarkCyan = property(get_DarkCyan, None)
    _Colors_Meta_.DarkGoldenrod = property(get_DarkGoldenrod, None)
    _Colors_Meta_.DarkGray = property(get_DarkGray, None)
    _Colors_Meta_.DarkGreen = property(get_DarkGreen, None)
    _Colors_Meta_.DarkKhaki = property(get_DarkKhaki, None)
    _Colors_Meta_.DarkMagenta = property(get_DarkMagenta, None)
    _Colors_Meta_.DarkOliveGreen = property(get_DarkOliveGreen, None)
    _Colors_Meta_.DarkOrange = property(get_DarkOrange, None)
    _Colors_Meta_.DarkOrchid = property(get_DarkOrchid, None)
    _Colors_Meta_.DarkRed = property(get_DarkRed, None)
    _Colors_Meta_.DarkSalmon = property(get_DarkSalmon, None)
    _Colors_Meta_.DarkSeaGreen = property(get_DarkSeaGreen, None)
    _Colors_Meta_.DarkSlateBlue = property(get_DarkSlateBlue, None)
    _Colors_Meta_.DarkSlateGray = property(get_DarkSlateGray, None)
    _Colors_Meta_.DarkTurquoise = property(get_DarkTurquoise, None)
    _Colors_Meta_.DarkViolet = property(get_DarkViolet, None)
    _Colors_Meta_.DeepPink = property(get_DeepPink, None)
    _Colors_Meta_.DeepSkyBlue = property(get_DeepSkyBlue, None)
    _Colors_Meta_.DimGray = property(get_DimGray, None)
    _Colors_Meta_.DodgerBlue = property(get_DodgerBlue, None)
    _Colors_Meta_.Firebrick = property(get_Firebrick, None)
    _Colors_Meta_.FloralWhite = property(get_FloralWhite, None)
    _Colors_Meta_.ForestGreen = property(get_ForestGreen, None)
    _Colors_Meta_.Fuchsia = property(get_Fuchsia, None)
    _Colors_Meta_.Gainsboro = property(get_Gainsboro, None)
    _Colors_Meta_.GhostWhite = property(get_GhostWhite, None)
    _Colors_Meta_.Gold = property(get_Gold, None)
    _Colors_Meta_.Goldenrod = property(get_Goldenrod, None)
    _Colors_Meta_.Gray = property(get_Gray, None)
    _Colors_Meta_.Green = property(get_Green, None)
    _Colors_Meta_.GreenYellow = property(get_GreenYellow, None)
    _Colors_Meta_.Honeydew = property(get_Honeydew, None)
    _Colors_Meta_.HotPink = property(get_HotPink, None)
    _Colors_Meta_.IndianRed = property(get_IndianRed, None)
    _Colors_Meta_.Indigo = property(get_Indigo, None)
    _Colors_Meta_.Ivory = property(get_Ivory, None)
    _Colors_Meta_.Khaki = property(get_Khaki, None)
    _Colors_Meta_.Lavender = property(get_Lavender, None)
    _Colors_Meta_.LavenderBlush = property(get_LavenderBlush, None)
    _Colors_Meta_.LawnGreen = property(get_LawnGreen, None)
    _Colors_Meta_.LemonChiffon = property(get_LemonChiffon, None)
    _Colors_Meta_.LightBlue = property(get_LightBlue, None)
    _Colors_Meta_.LightCoral = property(get_LightCoral, None)
    _Colors_Meta_.LightCyan = property(get_LightCyan, None)
    _Colors_Meta_.LightGoldenrodYellow = property(get_LightGoldenrodYellow, None)
    _Colors_Meta_.LightGray = property(get_LightGray, None)
    _Colors_Meta_.LightGreen = property(get_LightGreen, None)
    _Colors_Meta_.LightPink = property(get_LightPink, None)
    _Colors_Meta_.LightSalmon = property(get_LightSalmon, None)
    _Colors_Meta_.LightSeaGreen = property(get_LightSeaGreen, None)
    _Colors_Meta_.LightSkyBlue = property(get_LightSkyBlue, None)
    _Colors_Meta_.LightSlateGray = property(get_LightSlateGray, None)
    _Colors_Meta_.LightSteelBlue = property(get_LightSteelBlue, None)
    _Colors_Meta_.LightYellow = property(get_LightYellow, None)
    _Colors_Meta_.Lime = property(get_Lime, None)
    _Colors_Meta_.LimeGreen = property(get_LimeGreen, None)
    _Colors_Meta_.Linen = property(get_Linen, None)
    _Colors_Meta_.Magenta = property(get_Magenta, None)
    _Colors_Meta_.Maroon = property(get_Maroon, None)
    _Colors_Meta_.MediumAquamarine = property(get_MediumAquamarine, None)
    _Colors_Meta_.MediumBlue = property(get_MediumBlue, None)
    _Colors_Meta_.MediumOrchid = property(get_MediumOrchid, None)
    _Colors_Meta_.MediumPurple = property(get_MediumPurple, None)
    _Colors_Meta_.MediumSeaGreen = property(get_MediumSeaGreen, None)
    _Colors_Meta_.MediumSlateBlue = property(get_MediumSlateBlue, None)
    _Colors_Meta_.MediumSpringGreen = property(get_MediumSpringGreen, None)
    _Colors_Meta_.MediumTurquoise = property(get_MediumTurquoise, None)
    _Colors_Meta_.MediumVioletRed = property(get_MediumVioletRed, None)
    _Colors_Meta_.MidnightBlue = property(get_MidnightBlue, None)
    _Colors_Meta_.MintCream = property(get_MintCream, None)
    _Colors_Meta_.MistyRose = property(get_MistyRose, None)
    _Colors_Meta_.Moccasin = property(get_Moccasin, None)
    _Colors_Meta_.NavajoWhite = property(get_NavajoWhite, None)
    _Colors_Meta_.Navy = property(get_Navy, None)
    _Colors_Meta_.OldLace = property(get_OldLace, None)
    _Colors_Meta_.Olive = property(get_Olive, None)
    _Colors_Meta_.OliveDrab = property(get_OliveDrab, None)
    _Colors_Meta_.Orange = property(get_Orange, None)
    _Colors_Meta_.OrangeRed = property(get_OrangeRed, None)
    _Colors_Meta_.Orchid = property(get_Orchid, None)
    _Colors_Meta_.PaleGoldenrod = property(get_PaleGoldenrod, None)
    _Colors_Meta_.PaleGreen = property(get_PaleGreen, None)
    _Colors_Meta_.PaleTurquoise = property(get_PaleTurquoise, None)
    _Colors_Meta_.PaleVioletRed = property(get_PaleVioletRed, None)
    _Colors_Meta_.PapayaWhip = property(get_PapayaWhip, None)
    _Colors_Meta_.PeachPuff = property(get_PeachPuff, None)
    _Colors_Meta_.Peru = property(get_Peru, None)
    _Colors_Meta_.Pink = property(get_Pink, None)
    _Colors_Meta_.Plum = property(get_Plum, None)
    _Colors_Meta_.PowderBlue = property(get_PowderBlue, None)
    _Colors_Meta_.Purple = property(get_Purple, None)
    _Colors_Meta_.Red = property(get_Red, None)
    _Colors_Meta_.RosyBrown = property(get_RosyBrown, None)
    _Colors_Meta_.RoyalBlue = property(get_RoyalBlue, None)
    _Colors_Meta_.SaddleBrown = property(get_SaddleBrown, None)
    _Colors_Meta_.Salmon = property(get_Salmon, None)
    _Colors_Meta_.SandyBrown = property(get_SandyBrown, None)
    _Colors_Meta_.SeaGreen = property(get_SeaGreen, None)
    _Colors_Meta_.SeaShell = property(get_SeaShell, None)
    _Colors_Meta_.Sienna = property(get_Sienna, None)
    _Colors_Meta_.Silver = property(get_Silver, None)
    _Colors_Meta_.SkyBlue = property(get_SkyBlue, None)
    _Colors_Meta_.SlateBlue = property(get_SlateBlue, None)
    _Colors_Meta_.SlateGray = property(get_SlateGray, None)
    _Colors_Meta_.Snow = property(get_Snow, None)
    _Colors_Meta_.SpringGreen = property(get_SpringGreen, None)
    _Colors_Meta_.SteelBlue = property(get_SteelBlue, None)
    _Colors_Meta_.Tan = property(get_Tan, None)
    _Colors_Meta_.Teal = property(get_Teal, None)
    _Colors_Meta_.Thistle = property(get_Thistle, None)
    _Colors_Meta_.Tomato = property(get_Tomato, None)
    _Colors_Meta_.Transparent = property(get_Transparent, None)
    _Colors_Meta_.Turquoise = property(get_Turquoise, None)
    _Colors_Meta_.Violet = property(get_Violet, None)
    _Colors_Meta_.Wheat = property(get_Wheat, None)
    _Colors_Meta_.White = property(get_White, None)
    _Colors_Meta_.WhiteSmoke = property(get_WhiteSmoke, None)
    _Colors_Meta_.Yellow = property(get_Yellow, None)
    _Colors_Meta_.YellowGreen = property(get_YellowGreen, None)
class DisplayId(Structure):
    Value: UInt64
class IClosableNotifier(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.IClosableNotifier'
    _iid_ = Guid('{2989e93b-ed0f-5e79-90f2-eac592fc6e6a}')
    @winrt_commethod(6)
    def get_IsClosed(self) -> Boolean: ...
    @winrt_commethod(7)
    def add_Closed(self, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Closed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def add_FrameworkClosed(self, handler: win32more.Microsoft.UI.ClosableNotifierHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_FrameworkClosed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsClosed = property(get_IsClosed, None)
    Closed = event()
    FrameworkClosed = event()
class IColorHelper(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.IColorHelper'
    _iid_ = Guid('{3adddccd-3949-585b-a566-ccb8350dd221}')
class IColorHelperStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.IColorHelperStatics'
    _iid_ = Guid('{1d1d85a1-eb63-538a-84f0-019210bc406b}')
    @winrt_commethod(6)
    def FromArgb(self, a: Byte, r: Byte, g: Byte, b: Byte) -> win32more.Windows.UI.Color: ...
class IColorHelperStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.IColorHelperStatics2'
    _iid_ = Guid('{982a2d93-0ec4-56b7-9c20-0b5c77949066}')
    @winrt_commethod(6)
    def ToDisplayName(self, color: win32more.Windows.UI.Color) -> WinRT_String: ...
class IColors(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.IColors'
    _iid_ = Guid('{8cf15863-8411-5afd-946c-328e04da2f2f}')
class IColorsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.IColorsStatics'
    _iid_ = Guid('{8620a5b0-015a-57ac-a3f3-895d0b1269ae}')
    @winrt_commethod(6)
    def get_AliceBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def get_AntiqueWhite(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(8)
    def get_Aqua(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(9)
    def get_Aquamarine(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(10)
    def get_Azure(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(11)
    def get_Beige(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(12)
    def get_Bisque(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(13)
    def get_Black(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(14)
    def get_BlanchedAlmond(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(15)
    def get_Blue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(16)
    def get_BlueViolet(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(17)
    def get_Brown(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(18)
    def get_BurlyWood(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(19)
    def get_CadetBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(20)
    def get_Chartreuse(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(21)
    def get_Chocolate(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(22)
    def get_Coral(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(23)
    def get_CornflowerBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(24)
    def get_Cornsilk(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(25)
    def get_Crimson(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(26)
    def get_Cyan(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(27)
    def get_DarkBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(28)
    def get_DarkCyan(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(29)
    def get_DarkGoldenrod(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(30)
    def get_DarkGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(31)
    def get_DarkGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(32)
    def get_DarkKhaki(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(33)
    def get_DarkMagenta(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(34)
    def get_DarkOliveGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(35)
    def get_DarkOrange(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(36)
    def get_DarkOrchid(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(37)
    def get_DarkRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(38)
    def get_DarkSalmon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(39)
    def get_DarkSeaGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(40)
    def get_DarkSlateBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(41)
    def get_DarkSlateGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(42)
    def get_DarkTurquoise(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(43)
    def get_DarkViolet(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(44)
    def get_DeepPink(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(45)
    def get_DeepSkyBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(46)
    def get_DimGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(47)
    def get_DodgerBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(48)
    def get_Firebrick(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(49)
    def get_FloralWhite(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(50)
    def get_ForestGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(51)
    def get_Fuchsia(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(52)
    def get_Gainsboro(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(53)
    def get_GhostWhite(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(54)
    def get_Gold(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(55)
    def get_Goldenrod(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(56)
    def get_Gray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(57)
    def get_Green(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(58)
    def get_GreenYellow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(59)
    def get_Honeydew(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(60)
    def get_HotPink(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(61)
    def get_IndianRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(62)
    def get_Indigo(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(63)
    def get_Ivory(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(64)
    def get_Khaki(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(65)
    def get_Lavender(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(66)
    def get_LavenderBlush(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(67)
    def get_LawnGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(68)
    def get_LemonChiffon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(69)
    def get_LightBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(70)
    def get_LightCoral(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(71)
    def get_LightCyan(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(72)
    def get_LightGoldenrodYellow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(73)
    def get_LightGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(74)
    def get_LightGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(75)
    def get_LightPink(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(76)
    def get_LightSalmon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(77)
    def get_LightSeaGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(78)
    def get_LightSkyBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(79)
    def get_LightSlateGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(80)
    def get_LightSteelBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(81)
    def get_LightYellow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(82)
    def get_Lime(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(83)
    def get_LimeGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(84)
    def get_Linen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(85)
    def get_Magenta(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(86)
    def get_Maroon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(87)
    def get_MediumAquamarine(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(88)
    def get_MediumBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(89)
    def get_MediumOrchid(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(90)
    def get_MediumPurple(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(91)
    def get_MediumSeaGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(92)
    def get_MediumSlateBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(93)
    def get_MediumSpringGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(94)
    def get_MediumTurquoise(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(95)
    def get_MediumVioletRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(96)
    def get_MidnightBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(97)
    def get_MintCream(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(98)
    def get_MistyRose(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(99)
    def get_Moccasin(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(100)
    def get_NavajoWhite(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(101)
    def get_Navy(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(102)
    def get_OldLace(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(103)
    def get_Olive(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(104)
    def get_OliveDrab(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(105)
    def get_Orange(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(106)
    def get_OrangeRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(107)
    def get_Orchid(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(108)
    def get_PaleGoldenrod(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(109)
    def get_PaleGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(110)
    def get_PaleTurquoise(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(111)
    def get_PaleVioletRed(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(112)
    def get_PapayaWhip(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(113)
    def get_PeachPuff(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(114)
    def get_Peru(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(115)
    def get_Pink(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(116)
    def get_Plum(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(117)
    def get_PowderBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(118)
    def get_Purple(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(119)
    def get_Red(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(120)
    def get_RosyBrown(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(121)
    def get_RoyalBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(122)
    def get_SaddleBrown(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(123)
    def get_Salmon(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(124)
    def get_SandyBrown(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(125)
    def get_SeaGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(126)
    def get_SeaShell(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(127)
    def get_Sienna(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(128)
    def get_Silver(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(129)
    def get_SkyBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(130)
    def get_SlateBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(131)
    def get_SlateGray(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(132)
    def get_Snow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(133)
    def get_SpringGreen(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(134)
    def get_SteelBlue(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(135)
    def get_Tan(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(136)
    def get_Teal(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(137)
    def get_Thistle(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(138)
    def get_Tomato(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(139)
    def get_Transparent(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(140)
    def get_Turquoise(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(141)
    def get_Violet(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(142)
    def get_Wheat(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(143)
    def get_White(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(144)
    def get_WhiteSmoke(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(145)
    def get_Yellow(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(146)
    def get_YellowGreen(self) -> win32more.Windows.UI.Color: ...
    AliceBlue = property(get_AliceBlue, None)
    AntiqueWhite = property(get_AntiqueWhite, None)
    Aqua = property(get_Aqua, None)
    Aquamarine = property(get_Aquamarine, None)
    Azure = property(get_Azure, None)
    Beige = property(get_Beige, None)
    Bisque = property(get_Bisque, None)
    Black = property(get_Black, None)
    BlanchedAlmond = property(get_BlanchedAlmond, None)
    Blue = property(get_Blue, None)
    BlueViolet = property(get_BlueViolet, None)
    Brown = property(get_Brown, None)
    BurlyWood = property(get_BurlyWood, None)
    CadetBlue = property(get_CadetBlue, None)
    Chartreuse = property(get_Chartreuse, None)
    Chocolate = property(get_Chocolate, None)
    Coral = property(get_Coral, None)
    CornflowerBlue = property(get_CornflowerBlue, None)
    Cornsilk = property(get_Cornsilk, None)
    Crimson = property(get_Crimson, None)
    Cyan = property(get_Cyan, None)
    DarkBlue = property(get_DarkBlue, None)
    DarkCyan = property(get_DarkCyan, None)
    DarkGoldenrod = property(get_DarkGoldenrod, None)
    DarkGray = property(get_DarkGray, None)
    DarkGreen = property(get_DarkGreen, None)
    DarkKhaki = property(get_DarkKhaki, None)
    DarkMagenta = property(get_DarkMagenta, None)
    DarkOliveGreen = property(get_DarkOliveGreen, None)
    DarkOrange = property(get_DarkOrange, None)
    DarkOrchid = property(get_DarkOrchid, None)
    DarkRed = property(get_DarkRed, None)
    DarkSalmon = property(get_DarkSalmon, None)
    DarkSeaGreen = property(get_DarkSeaGreen, None)
    DarkSlateBlue = property(get_DarkSlateBlue, None)
    DarkSlateGray = property(get_DarkSlateGray, None)
    DarkTurquoise = property(get_DarkTurquoise, None)
    DarkViolet = property(get_DarkViolet, None)
    DeepPink = property(get_DeepPink, None)
    DeepSkyBlue = property(get_DeepSkyBlue, None)
    DimGray = property(get_DimGray, None)
    DodgerBlue = property(get_DodgerBlue, None)
    Firebrick = property(get_Firebrick, None)
    FloralWhite = property(get_FloralWhite, None)
    ForestGreen = property(get_ForestGreen, None)
    Fuchsia = property(get_Fuchsia, None)
    Gainsboro = property(get_Gainsboro, None)
    GhostWhite = property(get_GhostWhite, None)
    Gold = property(get_Gold, None)
    Goldenrod = property(get_Goldenrod, None)
    Gray = property(get_Gray, None)
    Green = property(get_Green, None)
    GreenYellow = property(get_GreenYellow, None)
    Honeydew = property(get_Honeydew, None)
    HotPink = property(get_HotPink, None)
    IndianRed = property(get_IndianRed, None)
    Indigo = property(get_Indigo, None)
    Ivory = property(get_Ivory, None)
    Khaki = property(get_Khaki, None)
    Lavender = property(get_Lavender, None)
    LavenderBlush = property(get_LavenderBlush, None)
    LawnGreen = property(get_LawnGreen, None)
    LemonChiffon = property(get_LemonChiffon, None)
    LightBlue = property(get_LightBlue, None)
    LightCoral = property(get_LightCoral, None)
    LightCyan = property(get_LightCyan, None)
    LightGoldenrodYellow = property(get_LightGoldenrodYellow, None)
    LightGray = property(get_LightGray, None)
    LightGreen = property(get_LightGreen, None)
    LightPink = property(get_LightPink, None)
    LightSalmon = property(get_LightSalmon, None)
    LightSeaGreen = property(get_LightSeaGreen, None)
    LightSkyBlue = property(get_LightSkyBlue, None)
    LightSlateGray = property(get_LightSlateGray, None)
    LightSteelBlue = property(get_LightSteelBlue, None)
    LightYellow = property(get_LightYellow, None)
    Lime = property(get_Lime, None)
    LimeGreen = property(get_LimeGreen, None)
    Linen = property(get_Linen, None)
    Magenta = property(get_Magenta, None)
    Maroon = property(get_Maroon, None)
    MediumAquamarine = property(get_MediumAquamarine, None)
    MediumBlue = property(get_MediumBlue, None)
    MediumOrchid = property(get_MediumOrchid, None)
    MediumPurple = property(get_MediumPurple, None)
    MediumSeaGreen = property(get_MediumSeaGreen, None)
    MediumSlateBlue = property(get_MediumSlateBlue, None)
    MediumSpringGreen = property(get_MediumSpringGreen, None)
    MediumTurquoise = property(get_MediumTurquoise, None)
    MediumVioletRed = property(get_MediumVioletRed, None)
    MidnightBlue = property(get_MidnightBlue, None)
    MintCream = property(get_MintCream, None)
    MistyRose = property(get_MistyRose, None)
    Moccasin = property(get_Moccasin, None)
    NavajoWhite = property(get_NavajoWhite, None)
    Navy = property(get_Navy, None)
    OldLace = property(get_OldLace, None)
    Olive = property(get_Olive, None)
    OliveDrab = property(get_OliveDrab, None)
    Orange = property(get_Orange, None)
    OrangeRed = property(get_OrangeRed, None)
    Orchid = property(get_Orchid, None)
    PaleGoldenrod = property(get_PaleGoldenrod, None)
    PaleGreen = property(get_PaleGreen, None)
    PaleTurquoise = property(get_PaleTurquoise, None)
    PaleVioletRed = property(get_PaleVioletRed, None)
    PapayaWhip = property(get_PapayaWhip, None)
    PeachPuff = property(get_PeachPuff, None)
    Peru = property(get_Peru, None)
    Pink = property(get_Pink, None)
    Plum = property(get_Plum, None)
    PowderBlue = property(get_PowderBlue, None)
    Purple = property(get_Purple, None)
    Red = property(get_Red, None)
    RosyBrown = property(get_RosyBrown, None)
    RoyalBlue = property(get_RoyalBlue, None)
    SaddleBrown = property(get_SaddleBrown, None)
    Salmon = property(get_Salmon, None)
    SandyBrown = property(get_SandyBrown, None)
    SeaGreen = property(get_SeaGreen, None)
    SeaShell = property(get_SeaShell, None)
    Sienna = property(get_Sienna, None)
    Silver = property(get_Silver, None)
    SkyBlue = property(get_SkyBlue, None)
    SlateBlue = property(get_SlateBlue, None)
    SlateGray = property(get_SlateGray, None)
    Snow = property(get_Snow, None)
    SpringGreen = property(get_SpringGreen, None)
    SteelBlue = property(get_SteelBlue, None)
    Tan = property(get_Tan, None)
    Teal = property(get_Teal, None)
    Thistle = property(get_Thistle, None)
    Tomato = property(get_Tomato, None)
    Transparent = property(get_Transparent, None)
    Turquoise = property(get_Turquoise, None)
    Violet = property(get_Violet, None)
    Wheat = property(get_Wheat, None)
    White = property(get_White, None)
    WhiteSmoke = property(get_WhiteSmoke, None)
    Yellow = property(get_Yellow, None)
    YellowGreen = property(get_YellowGreen, None)
class IconId(Structure):
    Value: UInt64
class WindowId(Structure):
    Value: UInt64


make_ready(__name__)
